pyqa
====

[![image](https://img.shields.io/pypi/v/pyqa.svg)](https://pypi.python.org/pypi/pyqa)

[![image](https://img.shields.io/travis/yusufadell/pyqa.svg)](https://travis-ci.com/yusufadell/pyqa)

[![Documentation Status](https://readthedocs.org/projects/pyqa/badge/?version=latest)](https://pyqa.readthedocs.io/en/latest/?version=latest)

Python console appliction that searches the internet for asnwers to coding problems

- Free software: Apache Software License 2.0
- Documentation: <https://pyqa.readthedocs.io>.

![screenshot](https://github.com/yusufadell/pyqa/raw/master/assets/screenshot.png)

Features
--------

- TODO

Credits
-------

This package was created with

[Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.
